@@ -1,10 +1,12 @@
 package Dist::Zilla::File::InMemory;
-BEGIN {
-  $Dist::Zilla::File::InMemory::VERSION = '4.101900';
+{
+  $Dist::Zilla::File::InMemory::VERSION = '4.300009';
 }
 # ABSTRACT: a file that you build entirely in memory
 use Moose;
 
+use namespace::autoclean;
+
 
 has content => (
   is  => 'rw',
@@ -14,7 +16,6 @@ has content => (
 
 with 'Dist::Zilla::Role::File';
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -26,7 +27,7 @@ Dist::Zilla::File::InMemory - a file that you build entirely in memory
 
 =head1 VERSION
 
-version 4.101900
+version 4.300009
 
 =head1 DESCRIPTION
 
@@ -40,7 +41,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
