@@ -1,17 +1,29 @@
 package Dist::Zilla::Plugin::MakeMaker;
-BEGIN {
-  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.200000';
+{
+  $Dist::Zilla::Plugin::MakeMaker::VERSION = '4.300009';
 }
 
 # ABSTRACT: build a Makefile.PL that uses ExtUtils::MakeMaker
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::PrereqSource';
-with 'Dist::Zilla::Role::InstallTool';
-with 'Dist::Zilla::Role::TextTemplate';
 
+use namespace::autoclean;
 
 use Config;
+use Data::Dumper ();
+use List::MoreUtils qw(any uniq);
+
+use Dist::Zilla::File::InMemory;
+use Dist::Zilla::Plugin::MakeMaker::Runner;
+
+
+
+has eumm_version => (
+  isa => 'Str',
+  is  => 'rw',
+  default => '6.30',
+);
+
 
 has 'make_path' => (
   isa => 'Str',
@@ -33,26 +45,27 @@ has '_runner' => (
   },
 );
 
-with 'Dist::Zilla::Role::BuildRunner';
-with 'Dist::Zilla::Role::TestRunner';
+# This is here, rather than at the top, so that the "build" and "test" methods
+# will exist, as they are required by BuildRunner and TestRunner respectively.
+# I had originally fixed this with stub methods, but stub methods to not behave
+# properly with this use case until Moose 2.0300. -- rjbs, 2012-02-08
+with qw(
+  Dist::Zilla::Role::BuildRunner
+  Dist::Zilla::Role::InstallTool
+  Dist::Zilla::Role::PrereqSource
+  Dist::Zilla::Role::TestRunner
+  Dist::Zilla::Role::TextTemplate
+);
 
-use Data::Dumper ();
-use List::MoreUtils qw(any uniq);
-
-use namespace::autoclean;
-
-use Dist::Zilla::File::InMemory;
-use Dist::Zilla::Plugin::MakeMaker::Runner;
-
-my $template = q|
+my $template = q!
 use strict;
 use warnings;
 
-{{ $perl_prereq ? qq[BEGIN { require $perl_prereq; }] : ''; }}
+{{ $perl_prereq ? qq[use $perl_prereq;] : ''; }}
 
 use ExtUtils::MakeMaker {{ $eumm_version }};
 
-{{ $share_dir_block[0] }}
+{{ $share_dir_code{preamble} || '' }}
 
 my {{ $WriteMakefileArgs }}
 
@@ -74,9 +87,9 @@ delete $WriteMakefileArgs{CONFIGURE_REQUIRES}
 
 WriteMakefile(%WriteMakefileArgs);
 
-{{ $share_dir_block[1] }}
+{{ $share_dir_code{postamble} || '' }}
 
-|;
+!;
 
 sub register_prereqs {
   my ($self) = @_;
@@ -94,27 +107,10 @@ sub register_prereqs {
   );
 }
 
-sub setup_installer {
-  my ($self, $arg) = @_;
-
-  (my $name = $self->zilla->name) =~ s/-/::/g;
-
-  my @exe_files =
-    $self->zilla->find_files(':ExecFiles')->map(sub { $_->name })->flatten;
-
-  $self->log_fatal("can't install files with whitespace in their names")
-    if grep { /\s/ } @exe_files;
-
-  my %test_dirs;
-  for my $file ($self->zilla->files->flatten) {
-    next unless $file->name =~ m{\At/.+\.t\z};
-    (my $dir = $file->name) =~ s{/[^/]+\.t\z}{/*.t}g;
-
-    $test_dirs{ $dir } = 1;
-  }
-
-  my @share_dir_block = (q{}, q{});
+sub share_dir_code {
+  my ($self) = @_;
 
+  my $share_dir_code = {};
 
   my $share_dir_map = $self->zilla->_share_dir_map;
   if ( keys %$share_dir_map ) {
@@ -132,15 +128,40 @@ sub setup_installer {
       }
     }
 
-    @share_dir_block = (
-      $preamble,
-      qq{package\nMY;\nuse File::ShareDir::Install qw(postamble);\n},
-    );
+    $share_dir_code->{preamble} = $preamble;
+    $share_dir_code->{postamble}
+      = qq{\{\npackage\nMY;\nuse File::ShareDir::Install qw(postamble);\n\}\n};
+  }
+
+  return $share_dir_code;
+}
+
+sub write_makefile_args {
+  my ($self) = @_;
+
+  (my $name = $self->zilla->name) =~ s/-/::/g;
+
+  my @exe_files =
+    $self->zilla->find_files(':ExecFiles')->map(sub { $_->name })->flatten;
+
+  $self->log_fatal("can't install files with whitespace in their names")
+    if grep { /\s/ } @exe_files;
+
+  my %test_dirs;
+  for my $file ($self->zilla->files->flatten) {
+    next unless $file->name =~ m{\At/.+\.t\z};
+    (my $dir = $file->name) =~ s{/[^/]+\.t\z}{/*.t}g;
+
+    $test_dirs{ $dir } = 1;
   }
 
   my $prereqs = $self->zilla->prereqs;
   my $perl_prereq = $prereqs->requirements_for(qw(runtime requires))
-                  ->as_string_hash->{perl};
+    ->clone
+    ->add_requirements($prereqs->requirements_for(qw(build requires)))
+    ->as_string_hash->{perl};
+
+  $perl_prereq = version->parse($perl_prereq)->numify if $perl_prereq;
 
   my $prereqs_dump = sub {
     $prereqs->requirements_for(@_)
@@ -153,6 +174,7 @@ sub setup_installer {
     = $prereqs->requirements_for(qw(build requires))
     ->clone
     ->add_requirements($prereqs->requirements_for(qw(test requires)))
+    ->clear_requirement('perl')
     ->as_string_hash;
 
   my %write_makefile_args = (
@@ -171,21 +193,34 @@ sub setup_installer {
     test => { TESTS => join q{ }, sort keys %test_dirs },
   );
 
-  $self->__write_makefile_args(\%write_makefile_args);
+  $write_makefile_args{MIN_PERL_VERSION} = $perl_prereq if $perl_prereq;
+
+  return \%write_makefile_args;
+}
+
+sub setup_installer {
+  my ($self, $arg) = @_;
+
+  my $write_makefile_args = $self->write_makefile_args;
+
+  $self->__write_makefile_args($write_makefile_args); # save for testing
+
+  my $perl_prereq = delete $write_makefile_args->{MIN_PERL_VERSION};
 
   my $makefile_args_dumper = Data::Dumper->new(
-    [ \%write_makefile_args ],
+    [ $write_makefile_args ],
     [ '*WriteMakefileArgs' ],
   );
   $makefile_args_dumper->Sortkeys( 1 );
   $makefile_args_dumper->Indent( 1 );
+  $makefile_args_dumper->Useqq( 1 );
 
   my $content = $self->fill_in_string(
     $template,
     {
       eumm_version      => \($self->eumm_version),
       perl_prereq       => \$perl_prereq,
-      share_dir_block   => \@share_dir_block,
+      share_dir_code    => $self->share_dir_code,
       WriteMakefileArgs => \($makefile_args_dumper->Dump),
     },
   );
@@ -205,14 +240,7 @@ has __write_makefile_args => (
   isa  => 'HashRef',
 );
 
-has 'eumm_version' => (
-  isa => 'Str',
-  is  => 'rw',
-  default => '6.31',
-);
-
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -224,7 +252,7 @@ Dist::Zilla::Plugin::MakeMaker - build a Makefile.PL that uses ExtUtils::MakeMak
 
 =head1 VERSION
 
-version 4.200000
+version 4.300009
 
 =head1 DESCRIPTION
 
@@ -232,13 +260,30 @@ This plugin will produce an L<ExtUtils::MakeMaker>-powered F<Makefile.PL> for
 the distribution.  If loaded, the L<Manifest|Dist::Zilla::Plugin::Manifest>
 plugin should also be loaded.
 
+=head1 ATTRIBUTES
+
+=head2 eumm_version
+
+This option declares the version of ExtUtils::MakeMaker required to configure
+and build the distribution.  It defaults to 6.30, which ensures a working
+C<INSTALL_BASE>.  It can be safely set to earlier versions, although I<no
+testing has been done to determine the minimum version actually required>.
+
+=head2 make_path
+
+This option sets the path to F<make>, used to build your dist and run tests.
+It defaults to the value for C<make> in L<Config>, or to C<make> if that isn't
+set.
+
+You probably won't need to set this option.
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
