@@ -1,12 +1,13 @@
 package Dist::Zilla::Plugin::Readme;
-BEGIN {
-  $Dist::Zilla::Plugin::Readme::VERSION = '4.101612';
+{
+  $Dist::Zilla::Plugin::Readme::VERSION = '4.300009';
 }
 # ABSTRACT: build a README file
 use Moose;
 use Moose::Autobox;
-with 'Dist::Zilla::Role::FileGatherer';
-with 'Dist::Zilla::Role::TextTemplate';
+with qw/Dist::Zilla::Role::FileGatherer Dist::Zilla::Role::TextTemplate/;
+
+use namespace::autoclean;
 
 
 sub gather_files {
@@ -40,7 +41,6 @@ version {{ $dist->version }}:
 }
 
 __PACKAGE__->meta->make_immutable;
-no Moose;
 1;
 
 __END__
@@ -52,7 +52,7 @@ Dist::Zilla::Plugin::Readme - build a README file
 
 =head1 VERSION
 
-version 4.101612
+version 4.300009
 
 =head1 DESCRIPTION
 
@@ -62,11 +62,11 @@ informative in the future.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
