@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::BeforeArchive;
-BEGIN {
-  $Dist::Zilla::Role::BeforeArchive::VERSION = '4.101900';
+{
+  $Dist::Zilla::Role::BeforeArchive::VERSION = '4.300009';
 }
 # ABSTRACT: something that runs before the archive file is built
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'before_archive';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::BeforeArchive - something that runs before the archive file i
 
 =head1 VERSION
 
-version 4.101900
+version 4.300009
 
 =head1 DESCRIPTION
 
@@ -34,7 +35,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
