@@ -1,15 +1,16 @@
 package Dist::Zilla::Role::FilePruner;
-BEGIN {
-  $Dist::Zilla::Role::FilePruner::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::FilePruner::VERSION = '4.300009';
 }
 # ABSTRACT: something that removes found files from the distribution
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+use namespace::autoclean;
+
 
 requires 'prune_files';
 
-no Moose::Role;
 1;
 
 __END__
@@ -21,7 +22,7 @@ Dist::Zilla::Role::FilePruner - something that removes found files from the dist
 
 =head1 VERSION
 
-version 4.200009
+version 4.300009
 
 =head1 DESCRIPTION
 
@@ -36,7 +37,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
