@@ -1,10 +1,12 @@
 package Dist::Zilla::Role::PluginBundle;
-BEGIN {
-  $Dist::Zilla::Role::PluginBundle::VERSION = '4.200009';
+{
+  $Dist::Zilla::Role::PluginBundle::VERSION = '4.300009';
 }
 # ABSTRACT: something that bundles a bunch of plugins
 use Moose::Role;
 
+use namespace::autoclean;
+
 
 sub register_component {
   my ($class, $name, $arg, $self) = @_;
@@ -14,7 +16,6 @@ sub register_component {
 
 requires 'bundle_config';
 
-no Moose::Role;
 1;
 
 __END__
@@ -26,7 +27,7 @@ Dist::Zilla::Role::PluginBundle - something that bundles a bunch of plugins
 
 =head1 VERSION
 
-version 4.200009
+version 4.300009
 
 =head1 DESCRIPTION
 
@@ -41,7 +42,7 @@ Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Ricardo SIGNES.
+This software is copyright (c) 2012 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
